# Autogenerated by Astropy's setup.py on 2019-06-15 04:46:19 UTC
from __future__ import unicode_literals
import datetime

version = "3.2.1"
githash = "3c27d0619e05ab4289587b61197f2b0b6ec38288"


major = 3
minor = 2
bugfix = 1

version_info = (major, minor, bugfix)

release = True
timestamp = datetime.datetime(2019, 6, 15, 4, 46, 19)
debug = False

astropy_helpers_version = "3.2.1"
